@@ -1,10 +1,12 @@
-use crate::{get::Get, put::Put, query::Query};
+use rusoto_dynamodb::GetItemInput;
+
+use crate::{key, put::Put, query::Query};
 
 /// Extension trait providing high level implementations of dynamodb requests
 pub trait DynamoDb: rusoto_dynamodb::DynamoDb + Clone {
     /// Perform a get item request
-    fn get<T: Get<Self>>(&self) -> T::Builder {
-        T::get(self.clone())
+    fn get<T: key::Builder<Self, GetItemInput>>(&self) -> T::Builder {
+        T::key(self.clone())
     }
     /// Perform a query request
     fn query<T: Query<Self>>(&self) -> T::Builder {
